"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const helper_1 = require("./helper");
const typescript_ilogger_1 = require("typescript-ilogger");
const test_values_1 = require("./test-values");
const error = new Error(`AWS Error`);
const getEventSourceMapping = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const invoke = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const invokeAsync = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const listEventSourceMappings = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
const updateEventSourceMapping = jest.fn().mockImplementation(() => {
    return Promise.reject(error);
});
jest.mock('@aws-sdk/client-lambda', () => {
    return {
        Lambda: jest.fn().mockImplementation(() => {
            return {
                getEventSourceMapping,
                invoke,
                invokeAsync,
                listEventSourceMappings,
                updateEventSourceMapping,
            };
        }),
    };
});
const logger = new typescript_ilogger_1.Logger(typescript_ilogger_1.LogLevel.Off);
const lambdaHelperMock = new helper_1.LambdaHelper(logger);
const TestValues = new test_values_1.TestingValues();
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.DisableDynamoEventSourceMappingAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = lambdaHelperMock.DisableDynamoEventSourceMappingAsync(TestValues.Name, TestValues.Uuid);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.DisableKinesisEventSourceMappingAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = lambdaHelperMock.DisableKinesisEventSourceMappingAsync(TestValues.Name, TestValues.Uuid);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.DisableSQSEventSourceMappingAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = lambdaHelperMock.DisableSQSEventSourceMappingAsync(TestValues.Name, TestValues.Uuid);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.EnableDynamoEventSourceMappingAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = lambdaHelperMock.EnableDynamoEventSourceMappingAsync(TestValues.Name, TestValues.Uuid);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.EnableKinesisEventSourceMappingAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = lambdaHelperMock.EnableKinesisEventSourceMappingAsync(TestValues.Name, TestValues.Uuid);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.EnableSQSEventSourceMappingAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = lambdaHelperMock.EnableSQSEventSourceMappingAsync(TestValues.Name, TestValues.Uuid);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.GetEventSourceMappingAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = lambdaHelperMock.GetEventSourceMappingAsync(TestValues.Uuid);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.ListEventSourceMappingsAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = lambdaHelperMock.ListEventSourceMappingsAsync(TestValues.Name, TestValues.Arn);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.InvokeSync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = lambdaHelperMock.InvokeSync(TestValues.Name, TestValues.Body);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.InvokeAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = lambdaHelperMock.InvokeAsync(TestValues.Name, TestValues.Body);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
describe(`${helper_1.LambdaHelper.name}.${lambdaHelperMock.UpdateEventSourceMappingAsync.name}`, () => {
    test(`${TestValues.InvalidTest}`, () => {
        const actual = lambdaHelperMock.UpdateEventSourceMappingAsync(TestValues.Name, TestValues.BooleanValue, TestValues.Uuid, TestValues.NumberValue);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
});
//# sourceMappingURL=helper-rejects.spec.js.map